@@ -8,12 +8,12 @@ homedir="/home/user/"
 defaultRecordFolder="/home/user/MyDocs/SleepAnalyser/" #users record dir with ending /
 ConfigFile="SleepAnalyser.conf"
 
-developmentconfigFolder="/home/gruinelli/Entwicklung/Maemo/Sleepanalyser/" #development PC
-developmentRecordFolder="/home/gruinelli/Entwicklung/Maemo/Sleepanalyser/data/" #development PC
+developmentconfigFolder="/home/gruinelli/Entwicklung/Maemo/GARAGE_SVN/Sleepanalyser/" #development PC
+developmentRecordFolder="/home/gruinelli/Entwicklung/Maemo/GARAGE_SVN/Sleepanalyser/data/" #development PC
 
 dateformat="%Y-%m-%d %H:%M:%S" #the date/time is stored in this format in the record files
 
-
+LogFile="/home/user/MyDocs/SleepAnalyser/SleepAnalyser.log" #Place for log file. IF YOU CHANGE THIS PATH, YOU ALSO HAVE TO CHANGE IT IN /usr/bin/sleepanalyser!
 
 
 GraphBitMap=""
