@@ -277,8 +277,8 @@ def SwitchModes(start):
                             if(data.PreviousProfile=="general"): #was general profile, change to silent profile
                                 cmd="dbus-send --type=method_call --dest=com.nokia.profiled /com/nokia/profiled com.nokia.profiled.set_profile string:\"silent\" | echo \"\""
                                 os.popen(cmd)
+                                print "Silent Profile activated"
                                 txt=_("Silent Profile activated")
-                                print txt
                                 cmd="dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:\""+txt+"\""
                                 os.popen(cmd)
                         except:
@@ -302,6 +302,7 @@ def SwitchModes(start):
                             if(data.PreviousProfile=="general"): #was general (before start measurement), so restore to general
                                 cmd="dbus-send --type=method_call --dest=com.nokia.profiled /com/nokia/profiled com.nokia.profiled.set_profile string:\"general\" | echo \"\""
                                 os.popen(cmd)  #set profile
+                                print "General Profile activated"
                                 txt=_("General Profile activated")
                                 cmd="dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:\""+txt+"\""
                                 os.popen(cmd)  #notification
