@@ -19,6 +19,7 @@ import os, sys
 
 import dbus
 from dbus.mainloop.qt import DBusQtMainLoop
+from time import strftime
 
 import data #own data
 import records #record data
@@ -30,6 +31,8 @@ data.app_path=os.path.dirname(__file__)
 if(data.app_path==""): data.app_path="./"
 else: data.app_path=data.app_path+"/"
 
+print strftime("%A %x %X")
+
 print "SleepAnalyser"
 
 #Load version file
@@ -42,12 +45,12 @@ try:
 except:
     print "Version file not found, please check your installation!"
 
-
 import kht_report  #Used for error reporting
 
 
 #check parameters
 if(len(sys.argv)>1):  #at least one parameter
+    print "Parameters:", sys.argv
     if(sys.argv[1]=="debug"):
         print "Enable Debug mode"
         data.debug=True
@@ -101,9 +104,6 @@ from Ui_AskForKeepWindow import *
 from Ui_AdditionalInfoWindow import *
 
 
-
-
-
 ###########################################################################
 ## Main function
 ##############o#############################################################
@@ -138,26 +138,24 @@ def main():
     if(MyLib_Imported==True): #module is loaded
         print "Mylib is compiled:", mylib.IsCompiled() #check if module is compiled
         if(mylib.IsCompiled()==False): #module is not compiled
-            txt= "SleepAnalyser:\nThe compiled module mylib.so could not get loaded! Please check if there is a never version "+ \
+            txt= "The compiled module mylib.so could not get loaded! Please check if there is a never version "+ \
                      "or inform the maintainer about it! SleepAnalyser will still work, " + \
                      "but some functions will work slow as we have to fall back to the unoptimised python code!"
             print txt
             cmd="dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteDialog " + \
-                     "string:\""+txt+"\" uint32:0 string:\"OK\""
+                     "string:\""+"SleepAnalyser:\n"+txt+"\" uint32:0 string:\"OK\""
             os.popen(cmd)
     else: #module is available but broken
-        txt="SleepAnalyser:\nSleepAnalyser could not load the module mylib.so\n" + \
+        txt="SleepAnalyser could not load the module mylib.so\n" + \
                  "in "+data.app_path+"lib. It might be corrupted. Please check if there is a never version "+ \
                  "or inform the maintainer about it! You can get SleepAnalyser working by removing the file "+data.app_path+"lib/mylib.so, " + \
                  "how ever some functions will work slow as we have to fall back to the unoptimised python code!"
         print txt
         cmd="dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteDialog " + \
-                 "string:\""+txt+"\" uint32:0 string:\"OK\""
+                 "string:\""+"SleepAnalyser:\n"+txt+"\" uint32:0 string:\"OK\""
         os.popen(cmd)
         exit()
 
-
-
     #Load Stylesheet
     try:
         file = open(data.configFolder+"UIStyle.css_user.css", 'r')
@@ -183,11 +181,6 @@ def main():
 #        except:
 #            print "Could not create user defined style sheet"
 
-
-
-
-
-
     StartWindow = frmStartWindow()
     StartWindow.show()
     StartWindow.UpdateScreenStart()
@@ -240,8 +233,10 @@ def EditUserName():
         if(data.user==""): data.user="-"
         config.set('main', 'user', str(data.user.encode( "utf-8" )))
 
-    print "User name:",  data.user
-
+    try:
+        print "User name:",  data.user
+    except:
+        pass
 
 
 
@@ -269,8 +264,8 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
             GenerateGraphBitmap(RecordWindow, False)
 
         if(records.Index==records.MaxArrayDataLen-1):
+            print "Memory is full!"
             txt=_('Memory is full!')
-            print txt
             data.Status=txt
             QtGui.QMessageBox.warning(RecordWindow, txt, _("You reached the end of the recording capacity!\nThe recording stops now."), QtGui.QMessageBox.Ok)
 #            RecordWindow.StopMeasurement()
@@ -292,8 +287,8 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
 #        print "Alarm is active"
         if(data.StopAfterAlarm==True): #stop recording
 #            print "Stop measurement, alarm is active"
+            print "Alarm got activated, stopped recording"
             txt=_("Alarm got activated, stopped recording")
-            print txt
             data.Status=txt
             StopMeasurement() #stop but keep alarm active!
 
@@ -336,7 +331,7 @@ def InitMeasurement():
     records.Sample_smoothing=data.Sample_smoothing
     records.Value_smoothing=data.Value_smoothing
     records.Trigger=data.Trigger #save Trigger level on start
-    records.statusID=_("OK")
+    records.statusID="OK"
 
     if(data.debug==True): PrintRecordData()
 
@@ -594,6 +589,7 @@ class frmStartWindow(QMainWindow):
                 data.RecordFilename=data.arrRecordFiles[l-1] #open last (youngest)record file
             else: #no RecordFiles in RecordFolder, show "open file" dialog
                 tmp=ViewWindow.ShowFileDialog()
+                print "## ShowViewWindow", tmp
                 if(not os.path.exists(tmp)): #only continue if valid record file selected
                     StartWindow.show()
                     ViewWindow.hide()
@@ -1193,6 +1189,7 @@ class frmViewWindow(QMainWindow):
                 data.RecordFilename=data.arrRecordFiles[data.arrRecordFilesIndex]
             else: #no RecordFiles in RecordFolder, show "open file" dialog
                 tmp=self.ShowFileDialog()
+                print "## DeleteRecord", tmp
                 if(tmp==""): #only continue if valid record file selected
                     self.closeEvent("") #no file selected, close
                     return
@@ -1223,18 +1220,23 @@ class frmViewWindow(QMainWindow):
 
 
         tmp=self.ShowFileDialog()
+        print "## OpenRecord", tmp
+        if(tmp==""): #if user presses cancel tmp will be empty
+            self.hide()
+            StartWindow.show()
         if(not os.path.exists(tmp)): #only continue if valid record file selected
             self.ui.lblStatus.hide()
+            print "file does not exist"
             return
-        tmp2=tmp.split("/")
+        tmp2=tmp.split("/") #tmp includes whole path + file name!
         l=len(tmp2)
-        data.RecordFilename=tmp2[l-1]
+        data.RecordFilename=tmp2[l-1] #extract file name
         data.RecordFolder=string.replace(tmp,  data.RecordFilename,  "") #get folder of selected file
         print "Set folder=",  data.RecordFolder,  ", file=",  data.RecordFilename
         LoadFileList()
         self.ShowRecord()
         self.ui.lblStatus.hide()
-        self.StatisticsCanvas.show()
+#        self.StatisticsCanvas.show()
 
 
     ###########################################################################
@@ -1304,6 +1306,7 @@ class frmViewWindow(QMainWindow):
         filename=string.replace(data.RecordFilename, ".csv",  "")
         tmp=QFileDialog.getSaveFileName(None,_("Export graph as"), data.defaultRecordFolder+filename, _("PNG-Image")+" (*.png)") #;;JPEG-Image (*.jpg)
         if(tmp!=""):
+            if(tmp[-4:]!=".png"): tmp=tmp+".png" #add file extention if missing
             print "Export graph as :",  tmp
             r=data.GraphBitMap.save(tmp,  "png",  -1)
             if(r==True): print "Export was successful"
